Sybase — SQLAlchemy 0.6.1 Documentation

# SQLAlchemy 0.6.1 Documentation

Search:
Version: 0.6.1 Last Updated: 05/31/2010 14:48:10

# Sybase

Support for Sybase Adaptive Server Enterprise (ASE).

Note that this dialect is no longer specific to Sybase iAnywhere. ASE is the primary support platform.

## python-sybase notes

Support for Sybase via the python-sybase driver.

http://python-sybase.sourceforge.net/

Connect strings are of the form:

    sybase+pysybase://<username>:<password>@<dsn>/[database name]

### Unicode Support

The python-sybase driver does not appear to support non-ASCII strings of any kind at this time.

## pyodbc notes

Support for Sybase via pyodbc.

http://pypi.python.org/pypi/pyodbc/

Connect strings are of the form:

    sybase+pyodbc://<username>:<password>@<dsn>/
    sybase+pyodbc://<username>:<password>@<host>/<database>

### Unicode Support

The pyodbc driver currently supports usage of these Sybase types with Unicode or multibyte strings:

    CHAR
    NCHAR
    NVARCHAR
    TEXT
    VARCHAR

Currently not supported are:

    UNICHAR
    UNITEXT
    UNIVARCHAR

## mxodbc notes

Support for Sybase via mxodbc.

This dialect is a stub only and is likely non functional at this time.